# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/version.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x66lyteidl/admin/version.proto\x12\x0e\x66lyteidl.admin\"a\n\x12GetVersionResponse\x12K\n\x15\x63ontrol_plane_version\x18\x01 \x01(\x0b\x32\x17.flyteidl.admin.VersionR\x13\x63ontrolPlaneVersion\"W\n\x07Version\x12\x14\n\x05\x42uild\x18\x01 \x01(\tR\x05\x42uild\x12\x18\n\x07Version\x18\x02 \x01(\tR\x07Version\x12\x1c\n\tBuildTime\x18\x03 \x01(\tR\tBuildTime\"\x13\n\x11GetVersionRequestB\xb2\x01\n\x12\x63om.flyteidl.adminB\x0cVersionProtoP\x01Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin\xa2\x02\x03\x46\x41X\xaa\x02\x0e\x46lyteidl.Admin\xca\x02\x0e\x46lyteidl\\Admin\xe2\x02\x1a\x46lyteidl\\Admin\\GPBMetadata\xea\x02\x0f\x46lyteidl::Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.admin.version_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.flyteidl.adminB\014VersionProtoP\001Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin\242\002\003FAX\252\002\016Flyteidl.Admin\312\002\016Flyteidl\\Admin\342\002\032Flyteidl\\Admin\\GPBMetadata\352\002\017Flyteidl::Admin'
  _globals['_GETVERSIONRESPONSE']._serialized_start=48
  _globals['_GETVERSIONRESPONSE']._serialized_end=145
  _globals['_VERSION']._serialized_start=147
  _globals['_VERSION']._serialized_end=234
  _globals['_GETVERSIONREQUEST']._serialized_start=236
  _globals['_GETVERSIONREQUEST']._serialized_end=255
# @@protoc_insertion_point(module_scope)
